@@ -1,5 +1,12 @@
 import pytest
-from constraint import Problem, MinConflictsSolver, BacktrackingSolver, OptimizedBacktrackingSolver, RecursiveBacktrackingSolver, ParallelSolver
+from constraint import (
+    Problem,
+    MinConflictsSolver,
+    BacktrackingSolver,
+    OptimizedBacktrackingSolver,
+    RecursiveBacktrackingSolver,
+    ParallelSolver,
+)
 from constraint import MaxProdConstraint, MinProdConstraint, MinSumConstraint, FunctionConstraint
 
 
@@ -19,7 +26,12 @@ def test_min_conflicts_solver():
     for _ in possible_solutions:
         solution = problem.getSolution()
         assert solution in possible_solutions
-        problem.addConstraint(FunctionConstraint(lambda x, y: (lambda x, y, xs, ys: x != xs or y != ys)(x, y, solution['x'], solution['y'])))
+        problem.addConstraint(
+            FunctionConstraint(
+                lambda x, y: (lambda x, y, xs, ys: x != xs or y != ys)(x, y, solution["x"], solution["y"])
+            )
+        )
+
 
 def test_backtracking_solvers():
     # setup the solvers
@@ -57,6 +69,7 @@ def test_backtracking_solvers():
     for problem in problems:
         validate(*problem.getSolutionsAsListDict(order=order))
 
+
 def test_recursive_backtracking_solver():
     problem = Problem(RecursiveBacktrackingSolver())
     problem.addVariable("x", [0, 1])
@@ -74,6 +87,7 @@ def test_recursive_backtracking_solver():
     assert solution in possible_solutions
     assert all(sol in possible_solutions for sol in solutions)
 
+
 def test_parallel_solver():
     # setup the solvers
     problem = Problem(ParallelSolver(process_mode=False))
@@ -100,6 +114,7 @@ def test_parallel_solver():
     assert size == len(true_solutions)
     assert all(sol in solutions_list for sol in true_solutions)
 
+
 def test_parallel_solver_process_mode():
     # setup the solvers
     problem = Problem(ParallelSolver(process_mode=True))
@@ -134,12 +149,19 @@ def test_parallel_solver_process_mode():
     with pytest.raises(AssertionError):
         problem.getSolutions()
 
+
 def test_solvers_consistency():
     """Test that the solvers yield consistent results for the same problem."""
-    solvers = [None, MinConflictsSolver(), OptimizedBacktrackingSolver(), BacktrackingSolver(), RecursiveBacktrackingSolver()]
+    solvers = [
+        None,
+        MinConflictsSolver(),
+        OptimizedBacktrackingSolver(),
+        BacktrackingSolver(),
+        RecursiveBacktrackingSolver(),
+    ]
     base_solution = None
     # variables = ['A','B','E','F','G','H','M']
-    variables = ['B','E','M']
+    variables = ["B", "E", "M"]
 
     def create_problem(solver):
         print(f"Creating problem with solver: {solver}")
@@ -166,7 +188,7 @@ def test_solvers_consistency():
             assert tuple(solution.values()) in base_solution
         else:
             solutions_list, _, size = problem.getSolutionsAsListDict(order=variables)
-        
+
             # Check that all solutions are valid
             assert size > 0, f"No solutions found for {solver}"
 
@@ -177,36 +199,50 @@ def test_solvers_consistency():
                 assert size == len(base_solution)
                 # assert all(sol in solutions_list for sol in base_solution)
 
+
 def test_mixed_type_constraints():
     """Test that mixed type constraints are handled correctly."""
     problem = Problem()
-    domains = {
-        "x": ["a", "b", "c"], 
-        "y": [True, False], 
-        "z": [0, 1],
-        "delta": ["a", True, 0.2]
-    }
+    domains = {"x": ["a", "b", "c"], "y": [True, False], "z": [0, 1], "delta": ["a", True, 0.2]}
     for var, domain in domains.items():
         problem.addVariable(var, domain)
-    constraints = [
-        "x != 'a' or y < z", 
-        "y or x != 'b'",
-        "delta == 0.2"
-    ]
+    constraints = ["x != 'a' or y < z", "y or x != 'b'", "delta == 0.2"]
     problem.addConstraint(constraints)
     solutions, _, _ = problem.getSolutionsAsListDict(order=list(domains.keys()))
-    
+
     possible_solutions = [
-        ('c', False, 1, 0.2), 
-        ('c', False, 0, 0.2), 
-        ('a', False, 1, 0.2), 
-        ('b', True, 0, 0.2), 
-        ('b', True, 1, 0.2), 
-        ('c', True, 0, 0.2), 
-        ('c', True, 1, 0.2), 
+        ("c", False, 1, 0.2),
+        ("c", False, 0, 0.2),
+        ("a", False, 1, 0.2),
+        ("b", True, 0, 0.2),
+        ("b", True, 1, 0.2),
+        ("c", True, 0, 0.2),
+        ("c", True, 1, 0.2),
     ]
 
     assert len(solutions) == len(possible_solutions), "Number of solutions does not match expected"
     assert len(set(solutions)) == len(possible_solutions), "Number of unique solutions does not match expected"
     for solution in solutions:
         assert solution in possible_solutions, f"Unexpected solution: {solution}"
+
+
+def test_negative_values():
+    """Test that negative values are handled correctly."""
+    problem = Problem()
+    problem.addVariable("x", [-2, -1, 1])
+    problem.addVariable("y", [-2, -1, 0])
+    problem.addConstraint("x + y >= -1")
+
+    solutions = problem.getSolutions()
+    solutions_list, _, size = problem.getSolutionsAsListDict(order=["x", "y"])
+
+    possible_solutions = [
+        {"x": 1, "y": 0},
+        {"x": -1, "y": 0},
+        {"x": 1, "y": -1},
+        {"x": 1, "y": -2},
+    ]
+    true_solutions = [tuple(sol.values()) for sol in possible_solutions]
+
+    assert size == len(true_solutions)
+    assert all(sol in solutions_list for sol in true_solutions)
